@@ -23,7 +23,12 @@ elif platform.system() == 'Windows': #open mp support on windows
             #extra_link_args=['/openmp'],
         )
     ]
-else:
+else: # macOS
+    '''IMPORTANT
+		Assuming "Homebrew" is already installed. To successfully compile meshCalc on macOS
+		you need to install gcc through Homebrew by:
+		brew install cmake gcc
+    '''
     os.environ['CC'] = 'gcc-10' # gcc-xx based on gcc version
     os.environ['CXX'] = 'g++-10' # g++-xx based on g++ version
     ext_modules = [
